const net = require('../../utils/net.js');
const util = require('../../utils/util.js');
import Poster from '../../utils/poster.js'
const {
  api_house_detail,
  api_house_collect,
  api_house_cancel_collect,
  api_get_QR
} = require('../../utils/api.js');


const app = getApp();
Page({

  /**
   * 页面的初始数据
   */
  data: {
    id: null,
    isLoading: true,
    bannerData: null,
    data: null,
    current: 1,
    isCollect: 0,
    markers: null,
    userInfo: null,

    showHomeBtn: false,
    isIPX: app.globalData.isIPX,
    posterArr: null,
    template: null,
    postImgSrc: null,
    isShowQRPoster: null,
    isShowCanvas: false,
    isShowPostMask: false,
    extendObj: null,
    shareQRImgSrc: null,


    videoSrc: null,
    poster: null,
    hidden: true
  },

  /**
   * 生命周期函数--监听页面加载 43831
   */
  onLoad: function (options) {
    const {
      scene,
      id,
      shareUid
    } = options;
    if (options && scene) {
      const parmasArr = scene.split('U'); // 通过U区分房源id跟用户userCode
      if (Array.isArray(parmasArr)) {
        this.data.id = parmasArr[0]
        this.getHouseDetail();
        if (parmasArr[1] && parmasArr[1].length) {
          const userCode = "U" + parmasArr[1]; // 拼接用户userCode
          util.setStorageSync('shareUid', userCode);
        }
      } else {
        util.showToast("房源正在维护中,请您稍后再试", null, true);
        setTimeout(function () {
          wx.reLaunch({
            url: '/pages/index/index'
          });
        }, 800);
      }
    } else if (options && id) {
      this.data.id = id;
      this.getHouseDetail();
      if (shareUid && shareUid.length) { // 分享用户id
        util.setStorageSync('shareUid', shareUid);
      }
    }

    const pages = getCurrentPages();
    if (pages.length == 1) {
      this.setData({
        showHomeBtn: true
      })
    }

    this.getUserInfo();

  },
  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {
    const {
      share
    } = this.data.data;

    let path = '/pages/houseDetail/houseDetail?id=' + this.data.id;
    const userInfo = util.getStorageSync('userInfo');
    if (userInfo && userInfo.userCode && userInfo.userCode.length) { // 分享用户id
      path = path + '&shareUid=' + userInfo.userCode;
    }

    return {
      title: share.shareTitle + share.shareContent,
      path: path,
      imageUrl: share.shareImgUrl,
      desc: share.shareContent
    }
  },

  loginCallback: function () {
    this.getUserInfo();
  },

  getUserInfo: function () {
    const userInfo = util.getStorageSync("userInfo");
    if (userInfo) {
      this.setData({
        userInfo: userInfo
      })
    }
  },

  getHouseDetail: function () {
    let params = {};
    params.url = api_house_detail;
    params.data = {
      id: this.data.id
    };
    net.req(params, true).then((data) => {
      this.dealWithData(data);
      this.getBarcode();
    }, (e) => {
      this.setData({
        isLoading: false,
        data: null
      });

      util.showToast(e.msg, null, true);

      setTimeout(() => {
        const pages = getCurrentPages();
        if (pages.length == 1) {
          this.goHomeAction();
        } else {
          wx.navigateBack();
        }
      }, 800);
    });

  },

  dealWithData: function (data) {
    let {
      photos,
      marketTags,
      name,
      moneyUnit,
      price,
      rentTimeUnit,
      priceSuffix,
      share
    } = data, tmp = new Array();
    for (var i = 0, n = marketTags.length; i < n; i++) {
      var obj = marketTags[i];
      obj.bgColor = util.colorToRgba(obj.bgColor);
      obj.color = util.colorToRgba(obj.color);
      marketTags[i] = obj;
    }
    data.marketTags = marketTags;
    this.setData({
      isLoading: false,
      data: data,
      markers: [{
        iconPath: '../../imgs/marker.png',
        id: 0,
        latitude: data.locationInfo.lat,
        longitude: data.locationInfo.lng,
        width: 28,
        height: 37
      }]
    });

    let extendObj = {
      img: share.shareImgUrl || "https://static.hoolihome.com/weapp/hoolihome/big_16_9.png",
      name,
      moneyUnit,
      price,
      rentTimeUnit,
      priceSuffix,
      marketTags
    }

    if (this.data.userInfo && this.data.userInfo.avatar && this.data.userInfo.avatar.length) {
      extendObj.avatar = this.data.userInfo.avatar
    }

    if (photos) {
      if (photos.videos && photos.videos.length) {
        tmp = tmp.concat(photos.videos);
      }
      if (photos.images && photos.images.length) {
        tmp = tmp.concat(photos.images);
      }
      this.setData({
        bannerData: tmp,
        isCollect: data.collection,
        extendObj: extendObj
      });
    }
  },

  tapBannerAction: function (e) {
    const {
      bannerItem
    } = e.currentTarget.dataset
    const data = this.data.data
    if (data.photos && parseInt(bannerItem.type) == 2) {
      if (data.photos.videos.length == 1) {
        this.setData({
          videoSrc: bannerItem.videoUrl,
          poster: bannerItem.imageUrl,
          hidden: false
        })
      } else {
        wx.navigateTo({
          url: '/pages/houseVideoImgs/houseVideoImgs?data=' + encodeURIComponent(JSON.stringify(data.photos)) + "&status=" + bannerItem.type
        });
      }
    } else {
      this.lookBigImage(bannerItem.imageUrl)
    }
  },


  lookBigImage(imageUrl) {
    const {
      photos
    } = this.data.data
    let imgArr = new Array()
    photos.images.forEach(item => {
      imgArr.push(item.imageUrl)
    });
    wx.previewImage({
      current: imageUrl, // 当前显示图片的http链接
      urls: imgArr // 需要预览的图片http链接列表
    })
  },

  bindchange: function (e) {
    let {
      current
    } = e.detail;
    this.setData({
      current: current + 1
    })
  },


  lookAllHouseAction: function () {
    wx.navigateTo({
      url: '/pages/allHouse/allHouse?houseId=' + this.data.id
    });
  },

  applyRoomItemAction: function (e) {
    let data = this.data.data;
    const {
      currentItem
    } = e.currentTarget.dataset;

    let params = {
      roomId: currentItem ? currentItem.roomId : "",
      countryId: data.countryId || "",
      cityId: data.cityId || "",
      name: currentItem ? currentItem.roomName : data.name,
      rentTime: currentItem ? currentItem.rentTime : data.rentTime,
      moneyUnit: currentItem ? currentItem.moneyUnit : data.moneyUnit,
      price: currentItem ? currentItem.price : data.price,
      rentTimeUnit: currentItem ? currentItem.rentTimeUnit : data.rentTimeUnit,
      rentNum: currentItem ? currentItem.rentNum : data.rentNum,
      imgObj: {
        imageUrl: currentItem.images
      },
      id: data.id
    }

    this.openApplyReserve(params);
  },

  applyRoomAction: function (e) {
    let data = this.data.data;
    let params = {
      countryId: data.countryId,
      cityId: data.cityId,
      name: data.name,
      rentTime: data.rentTime,
      moneyUnit: data.moneyUnit,
      price: data.price,
      rentTimeUnit: data.rentTimeUnit,
      rentNum: data.rentNum,
      id: data.id
    }


    if (data.photos && data.photos.images && data.photos.images.length) {
      params.imgObj = data.photos.images[0];
    }

    this.openApplyReserve(params);

  },

  openApplyReserve: function (data) {
    if (this.data.userInfo) {
      wx.navigateTo({
        url: '/pages/applyReserve/applyReserve?data=' + JSON.stringify(data)
      });
    } else {
      wx.navigateTo({
        url: '/pages/login/login'
      });
    }
  },

  collectAction: function () {
    if (this.data.userInfo) {
      const isCollect = this.data.isCollect;
      let params = {};
      params.url = isCollect == 1 ? api_house_cancel_collect : api_house_collect;
      params.data = {
        cate: 1,
        hid: this.data.id
      };
      net.req(params, true).then((data) => {
        this.setData({
          isCollect: !isCollect
        });
      }, (e) => {

      });
    } else {
      wx.navigateTo({
        url: '/pages/login/login'
      });
    }
  },

  tapMapAction: function () {
    const data = this.data.data;
    if (data.locationInfo.lat && data.locationInfo.lat.length && data.locationInfo.lng && data.locationInfo.lng.length) {
      const webUrl = data.locationInfo.detailUrl + "&bigMap=map"
      wx.navigateTo({
        url: `/pages/webView/webView?webUrl=${encodeURIComponent(webUrl)}`
      });
    }
  },


  copyHouseNumAction: function () {
    const {
      code
    } = this.data.data;
    wx.setClipboardData({
      data: code,
      success(res) {}
    })
  },

  lookProtocolAction: function () {
    const data = this.data.data;
    if (data.protocol && data.protocol.length) {
      wx.navigateTo({
        url: `/pages/webView/webView?webUrl=${encodeURIComponent(data.protocol)}`
      });
    }
  },

  tapLookMoreAction: function (e) {
    const {
      detailUrl
    } = e.currentTarget.dataset
    wx.navigateTo({
      url: `/pages/webView/webView?webUrl=${encodeURIComponent(detailUrl)}&name=房源详情`
    });
  },

  shareAction: function () {
    if (this.data.postImgSrc) {
      this.setData({
        showMask: true
      });
    } else {
      util.showToast("分享优化中,请使用微信小程序自带分享...", null, true);
    }
  },

  getBarcode: function () {
    let {
      userInfo,
      id,
      data
    } = this.data;
    let shareToken = id;
    if (userInfo && userInfo.userCode && userInfo.userCode.length) {
      shareToken += userInfo.userCode
    }

    shareToken = shareToken.length > 32 ? shareToken.substring(0, 31) : shareToken; // 做容错判断,超过32位
    let params = {};
    params.url = api_get_QR;
    params.data = {
      project: data.share.project,
      scene: shareToken,
      page: data.share.smallProjectPath,
      width: 150,
      contentType: data.share.contentType
    };
    net.req(params).then((res) => {
      let postImgSrc = res.host + res.url;
      this.setData({
        postImgSrc: postImgSrc,
        isShowQRPoster: true
      });
    });
  },

  maskHide: function () {
    this.setData({
      showMask: false
    });
  },

  postMaskHide: function () {
    this.setData({
      isShowPostMask: false
    });
  },


  goHomeAction: function () {
    wx.reLaunch({
      url: '/pages/index/index'
    });
  },


  posterCallack: function (arr) {
    if (!arr) return;
    arr.forEach((v, i, a) => {
      let {
        id,
        dataset
      } = v;
      if (id.indexOf('img') !== -1) {
        wx.getImageInfo({
          src: dataset.what,
          success: (res) => {
            v.dataset.uri = res.path;
          }
        });
      }
    });
    this.data.posterArr = arr

  },
  onImgOK: function (e) {
    const canvasSrc = e.detail.path;
    wx.hideLoading();

    this.setData({
      isShowCanvas: false
    }, () => {
      this.setData({
        shareQRImgSrc: canvasSrc
      })

      wx.previewImage({
        current: canvasSrc, // 当前显示图片的http链接
        urls: [canvasSrc] // 需要预览的图片http链接列表
      })
    });
  },

  handleGeneratePoster: function () {
    const _this = this;
    if (this.data.shareQRImgSrc) {
      wx.previewImage({
        current: this.data.shareQRImgSrc, // 当前显示图片的http链接
        urls: [this.data.shareQRImgSrc] // 需要预览的图片http链接列表
      })
      return;
    }

    _this.setData({
      showMask: false,
      isShowCanvas: true,
      isShowQRPoster: false
    }, () => {
      let palette = new Poster().palette(this.data.posterArr);
      this.setData({
        template: palette
      });
      wx.showLoading({
        title: '生成海报中...'
      });
    });


  },
  saveImgAction: function () {
    const _this = this;
    wx.saveImageToPhotosAlbum({
      filePath: this.data.shareQRImgSrc,
      success(res) {
        wx.showToast({
          title: '保存成功',
          icon: 'none',
          duration: 1000
        });
        _this.setData({
          isShowPostMask: false
        })
      },
      fail() {
        wx.showModal({
          title: '授权失败',
          content: '是否打开小程序设置界面，完成对该小程序授权状态',
          success: function (res) {
            if (res.confirm) {
              wx.openSetting({
                success(res) {}
              })
            }
          }
        })
      }
    })
  },


  hiddenVideoToast: function () {
    this.setData({
      videoSrc: null,
      poster: null,
      hidden: true
    }, () => {

    })
  },

})