const net = require('../../utils/net.js');
const util = require('../../utils/util.js');
const {
  api_index_home
} = require('../../utils/api.js');

const app = getApp();
Page({
  /**
   * 页面的初始数据
   */
  data: {
    isLoading: true,
    citySelectObj: null,
    selectedIndex: 0,
    isIPX: app.globalData.isIPX,
    homeData: null,
    userInfo: null,
  },

  onHide: function () {
    this.setData({
      isLoading: false
    })
  },


  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    const {
      shareUid,
      shareCrmUid
    } = options;
    if (shareUid && shareUid.length) { // 分享用户id
      util.setStorageSync('shareUid', shareUid);
    }
    if (shareCrmUid && shareCrmUid.length) { // 分享管理端id
      util.setStorageSync('shareCrmUid', shareCrmUid);
    }

    let {
      citySelectObj
    } = this.data;
    citySelectObj = util.getStorageSync('citySelectObj');
    if (!citySelectObj) {
      wx.reLaunch({
        url: '/pages/citySelect/citySelect',
      });
      return false;
    } else {
      this.setData({
        citySelectObj: citySelectObj
      });
      this.loadHomeData();
    }

    this.getUserInfo();
  },
  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {
    const userInfo = util.getStorageSync('userInfo');
    let path = "/pages/index/index";
    if (userInfo && userInfo.userCode) { // 分享用户id
      path = path + `?shareUid=${userInfo.userCode}`
    }
    return {
      title: "hooli找房",
      path: path,
      imageUrl: "https://static.hoolihome.com/weapp/hoolihome/share.jpg"
    }
  },


  onPullDownRefresh: function () {
    if (this.data.selectedIndex == 0) {
      this.loadHomeData();
    } else {
      wx.stopPullDownRefresh();
    }
  },





  getUserInfo: function () {
    const userInfo = util.getStorageSync("userInfo");
    if (userInfo) {
      this.setData({
        userInfo: userInfo
      })
    }
  },

  loadHomeData: function () {
    let params = {};
    params.url = api_index_home;
    params.data = {
      cityId: this.data.citySelectObj.id
    };
    net.req(params, true).then((data) => {
      this.setData({
        isLoading: false,
        homeData: data
      });
      wx.stopPullDownRefresh();
    }, (e) => {
      this.setData({
        isLoading: false,
        homeData: null
      });
      wx.stopPullDownRefresh();
    });
  },

  dealWithData: function (data) {
    let obj = {};
    for (let i = 0, n = data.length; i < n; i++) {
      let tmp = data[i],
        cate = parseInt(tmp.cate);
      if (cate == 5) {
        obj.banner = tmp.data;
      } else if (cate == 6) {
        obj.box = tmp.data;
      } else if (cate == 1) {
        obj.house = tmp;
      } else if (cate == 8) {
        obj.video = tmp;
      } else {
        obj.publicity = tmp.data;
      }
    }
    this.setData({
      isLoading: false,
      homeData: obj
    });
  },

  tabTabbarAction: function (e) {
    let {
      id
    } = e.detail;
    this.setData({
      selectedIndex: id
    });

    if (!this.data.userInfo) {
      this.getUserInfo();
    }
  }
})